@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-04-07'; # DATE
-our $VERSION = '0.38'; # VERSION
+our $DATE = '2015-04-08'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -332,11 +332,15 @@ sub _process_script {
 
             my $check_common_arg = sub {
                 my ($opts, $name) = @_;
-                'common' ~~ @{ $opts->{$name}{tags} // []};
+                return 1 if 'common' ~~ @{ $opts->{$name}{tags} // []};
+                return 1 if !$opts->{$name}{arg};
+                0;
             };
 
-            # first display options tagged with 'common' (that are supposed to
-            # be the same across subcommands)
+            # first display options tagged with 'common' as well as common
+            # option (non-function argument option, like --format or
+            # --log-level). these are supposed to be the same across
+            # subcommands.
             {
                 use experimental 'smartmatch';
                 my $opts = $clidocdata{ $sc_names[0] }{opts};
@@ -496,11 +500,13 @@ sub _process_script {
             );
 
             if ($cli->{subcommands}) {
-                # first list the options tagged with 'common'
+                # first list the options tagged with 'common' and common options
+                # (non-function argument options, like --format or --log-level)
+                # which are supposed to be the same across subcommands.
                 push @content, "=head2 Common for all subcommands\n\n";
                 my $param2opts = $self->_list_config_params(
                     $clidocdata{$sc_names[0]},
-                    sub { 'common' ~~ @{ $_[0]->{tags} // []} });
+                    sub { 'common' ~~ @{ $_[0]->{tags} // []} || !$_[0]->{arg} });
                 for (sort keys %$param2opts) {
                     push @content, " $_ (see $param2opts->{$_})\n";
                 }
@@ -513,7 +519,7 @@ sub _process_script {
                     push @content, "=head2 For subcommand '$sc_name'\n\n";
                     $param2opts = $self->_list_config_params(
                         $clidocdata{$sc_name},
-                        sub { !('common' ~~ @{ $_[0]->{tags} // []}) });
+                        sub { !('common' ~~ @{ $_[0]->{tags} // []}) && $_[0]->{arg} });
                     for (sort keys %$param2opts) {
                         push @content, " $_ (see $param2opts->{$_})\n";
                     }
@@ -605,7 +611,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.38 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
+This document describes version 0.39 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-08.
 
 =head1 SYNOPSIS
 
@@ -708,7 +714,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
 
 =head1 BUGS
 
